/*
 * @(#)BoardKeyHandler.java				1.00
 * 
 * Copyright (C) Ramin Rakhamimov
 * ramin32@gmail.com
 * http://www.ramrak.net
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.ramrak.applications.thechessgame.eventhandlers;

import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.util.Map;

import javax.swing.JPanel;

import net.ramrak.applications.thechessgame.pieces.BoardPiece;
import net.ramrak.applications.thechessgame.pieces.PiecePosition;

/**
 * Moves pieces on the board via the arrow keys. 
 * @author Ramin Rakhamimov
 */
public class BoardKeyHandler extends KeyAdapter {
	private PiecePosition position;
	private PiecePosition oldPosition;
	private final JPanel panel;
	private final Map<PiecePosition, BoardPiece> boardMap;

	public BoardKeyHandler(JPanel panel, Map<PiecePosition, BoardPiece> map) {
		this.panel = panel;
		this.boardMap = map;
		panel.setFocusable(true);

		position = PiecePosition.createFromString("E5");
	}

	public void keyPressed(KeyEvent event) {
		try {
			if (event.getKeyCode() == KeyEvent.VK_LEFT)
				position = position.left();
			if (event.getKeyCode() == KeyEvent.VK_RIGHT)
				position = position.right();
			if (event.getKeyCode() == KeyEvent.VK_UP)
				position = position.up();
			if (event.getKeyCode() == KeyEvent.VK_DOWN)
				position = position.down();
			if (event.getKeyCode() == KeyEvent.VK_ENTER) {
				if (oldPosition == null && boardMap.get(position) != null) {
					oldPosition = position;

				} else if (oldPosition != null) {
					boardMap.put(position, boardMap.remove(oldPosition));
					oldPosition = null;
				}
			}
		} catch (IllegalArgumentException e) {
			return;
		}
		panel.repaint();

	}

	public PiecePosition getCurrentPosition() {
		return position;
	}

}
