/*
 * @(#)ChessImageToolKit.java				1.00
 * 
 * Copyright (C) Ramin Rakhamimov
 * ramin32@gmail.com
 * http://www.ramrak.net
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


package net.ramrak.applications.thechessgame.helpers;

import java.awt.Image;

import javax.swing.ImageIcon;

import net.ramrak.applications.thechessgame.pieces.PieceColor;
import net.ramrak.applications.thechessgame.pieces.PieceType;

/**
 * Provides easy access to all the images used in the game.
 * 
 * @author Ramin Rakhamimov
 */
public final class ChessImageToolKit {

	public final static Image DARK_SQUARE = getImage("/images/board/darkSquare.png");
	public final static Image LIGHT_SQUARE = getImage("/images/board/lightSquare.png");

	public final static Image WHITE_PAWN = getImage("/images/pieces/WHITE_PAWN.png");
	public final static Image WHITE_ROOK = getImage("/images/pieces/WHITE_ROOK.png");
	public final static Image WHITE_KNIGHT = getImage("/images/pieces/WHITE_KNIGHT.png");
	public final static Image WHITE_BISHOP = getImage("/images/pieces/WHITE_BISHOP.png");
	public final static Image WHITE_KING = getImage("/images/pieces/WHITE_KING.png");
	public final static Image WHITE_QUEEN = getImage("/images/pieces/WHITE_QUEEN.png");

	public final static Image BLACK_PAWN = getImage("/images/pieces/BLACK_PAWN.png");
	public final static Image BLACK_ROOK = getImage("/images/pieces/BLACK_ROOK.png");
	public final static Image BLACK_KNIGHT = getImage("/images/pieces/BLACK_KNIGHT.png");
	public final static Image BLACK_BISHOP = getImage("/images/pieces/BLACK_BISHOP.png");
	public final static Image BLACK_KING = getImage("/images/pieces/BLACK_KING.png");
	public final static Image BLACK_QUEEN = getImage("/images/pieces/BLACK_QUEEN.png");

	private ChessImageToolKit() {
	}

	;// Prevent instantiation.

	private static Image getImage(String str) {
		return new ImageIcon(ChessImageToolKit.class.getResource(str))
				.getImage();
	}

	public static Image getPiece(PieceType type, PieceColor color) {
		if (color == PieceColor.BLACK) {
			switch (type) {
			case PAWN:
				return BLACK_PAWN;
			case ROOK:
				return BLACK_ROOK;
			case KNIGHT:
				return BLACK_KNIGHT;
			case BISHOP:
				return BLACK_BISHOP;
			case QUEEN:
				return BLACK_QUEEN;
			case KING:
				return BLACK_KING;
			}
		} else {
			switch (type) {
			case PAWN:
				return WHITE_PAWN;
			case ROOK:
				return WHITE_ROOK;
			case KNIGHT:
				return WHITE_KNIGHT;
			case BISHOP:
				return WHITE_BISHOP;
			case QUEEN:
				return WHITE_QUEEN;
			case KING:
				return WHITE_KING;
			}
		}
		return null;
	}

	public static int getSquareSize() {
		return LIGHT_SQUARE.getWidth(null);
	}
}
