/*
 * @(#)BoardMapInitializer.java				1.00
 * 
 * Copyright (C) Ramin Rakhamimov
 * ramin32@gmail.com
 * http://www.ramrak.net
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


package net.ramrak.applications.thechessgame.helpers;

import java.util.HashMap;
import java.util.Map;

import net.ramrak.applications.thechessgame.pieces.BoardPiece;
import net.ramrak.applications.thechessgame.pieces.PieceColor;
import net.ramrak.applications.thechessgame.pieces.PiecePosition;
import net.ramrak.applications.thechessgame.pieces.PieceType;

/**
 * Creates instances of chess board games
 * @author Ramin Rakhamimov
 */
public final class GameMapFactory {
	private GameMapFactory() {
	} // make uninstatiable.

	public static Map<PiecePosition, BoardPiece> getChessGame() {
		Map<PiecePosition, BoardPiece> boardMap = new HashMap<PiecePosition, BoardPiece>();
		boardMap.put(PiecePosition.createFromString("A1"), new BoardPiece(
				PieceType.ROOK, PieceColor.WHITE));
		boardMap.put(PiecePosition.createFromString("B1"), new BoardPiece(
				PieceType.KNIGHT, PieceColor.WHITE));
		boardMap.put(PiecePosition.createFromString("C1"), new BoardPiece(
				PieceType.BISHOP, PieceColor.WHITE));
		boardMap.put(PiecePosition.createFromString("D1"), new BoardPiece(
				PieceType.KING, PieceColor.WHITE));
		boardMap.put(PiecePosition.createFromString("E1"), new BoardPiece(
				PieceType.QUEEN, PieceColor.WHITE));
		boardMap.put(PiecePosition.createFromString("F1"), new BoardPiece(
				PieceType.BISHOP, PieceColor.WHITE));
		boardMap.put(PiecePosition.createFromString("G1"), new BoardPiece(
				PieceType.KNIGHT, PieceColor.WHITE));
		boardMap.put(PiecePosition.createFromString("H1"), new BoardPiece(
				PieceType.ROOK, PieceColor.WHITE));
		boardMap.put(PiecePosition.createFromString("A2"), new BoardPiece(
				PieceType.PAWN, PieceColor.WHITE));
		boardMap.put(PiecePosition.createFromString("B2"), new BoardPiece(
				PieceType.PAWN, PieceColor.WHITE));
		boardMap.put(PiecePosition.createFromString("C2"), new BoardPiece(
				PieceType.PAWN, PieceColor.WHITE));
		boardMap.put(PiecePosition.createFromString("D2"), new BoardPiece(
				PieceType.PAWN, PieceColor.WHITE));
		boardMap.put(PiecePosition.createFromString("E2"), new BoardPiece(
				PieceType.PAWN, PieceColor.WHITE));
		boardMap.put(PiecePosition.createFromString("F2"), new BoardPiece(
				PieceType.PAWN, PieceColor.WHITE));
		boardMap.put(PiecePosition.createFromString("G2"), new BoardPiece(
				PieceType.PAWN, PieceColor.WHITE));
		boardMap.put(PiecePosition.createFromString("H2"), new BoardPiece(
				PieceType.PAWN, PieceColor.WHITE));

		// BLACK
		boardMap.put(PiecePosition.createFromString("A8"), new BoardPiece(
				PieceType.ROOK, PieceColor.BLACK));
		boardMap.put(PiecePosition.createFromString("B8"), new BoardPiece(
				PieceType.KNIGHT, PieceColor.BLACK));
		boardMap.put(PiecePosition.createFromString("C8"), new BoardPiece(
				PieceType.BISHOP, PieceColor.BLACK));
		boardMap.put(PiecePosition.createFromString("D8"), new BoardPiece(
				PieceType.KING, PieceColor.BLACK));
		boardMap.put(PiecePosition.createFromString("E8"), new BoardPiece(
				PieceType.QUEEN, PieceColor.BLACK));
		boardMap.put(PiecePosition.createFromString("F8"), new BoardPiece(
				PieceType.BISHOP, PieceColor.BLACK));
		boardMap.put(PiecePosition.createFromString("G8"), new BoardPiece(
				PieceType.KNIGHT, PieceColor.BLACK));
		boardMap.put(PiecePosition.createFromString("H8"), new BoardPiece(
				PieceType.ROOK, PieceColor.BLACK));
		boardMap.put(PiecePosition.createFromString("A7"), new BoardPiece(
				PieceType.PAWN, PieceColor.BLACK));
		boardMap.put(PiecePosition.createFromString("B7"), new BoardPiece(
				PieceType.PAWN, PieceColor.BLACK));
		boardMap.put(PiecePosition.createFromString("C7"), new BoardPiece(
				PieceType.PAWN, PieceColor.BLACK));
		boardMap.put(PiecePosition.createFromString("D7"), new BoardPiece(
				PieceType.PAWN, PieceColor.BLACK));
		boardMap.put(PiecePosition.createFromString("E7"), new BoardPiece(
				PieceType.PAWN, PieceColor.BLACK));
		boardMap.put(PiecePosition.createFromString("F7"), new BoardPiece(
				PieceType.PAWN, PieceColor.BLACK));
		boardMap.put(PiecePosition.createFromString("G7"), new BoardPiece(
				PieceType.PAWN, PieceColor.BLACK));
		boardMap.put(PiecePosition.createFromString("H7"), new BoardPiece(
				PieceType.PAWN, PieceColor.BLACK));
		return boardMap;
	}
}
